decline_fit.exponential_fit: S3 method for class 'decline_fit'
Description
Return a list of estimated parameters for the Arps exponential decline model
Usage
# S3 method for exponential_fit
decline_fit(decline_fit_lst, time_lst)
Arguments
decline_fit_lst
a list object of class 'decline_fit'
time_lst
a list object of class 'time'
Value
a list of estimates for the parameters of the Arps exponential model